# UAV Detection System

基于 ONNX 的无人机检测系统，支持单张图片和批量处理。

## 功能特点

- 支持 ONNX 模型推理
- 支持 CUDA 加速
- 支持批量处理图片
- 自动生成检测报告（CSV格式）
- 支持误报过滤
- 支持检测框面积比例限制
- 支持保存未检测到目标的图片

## 环境要求

- Python 3.8+
- OpenCV 4.5+
- ONNX Runtime 1.9+
- CUDA 11.0+ (可选，用于GPU加速)

## 安装依赖

```bash
pip install -r requirements.txt
```

## 使用方法

### 命令行模式

```bash
# 处理单张图片
python -m src.core.inference --input path/to/image.jpg --output results

# 处理整个目录
python -m src.core.inference --input path/to/images_dir --output results

# 调整检测参数
python -m src.core.inference --input path/to/image.jpg --threshold 0.6 --max-bbox-ratio 0.1

# 保存未检测到目标的图片
python -m src.core.inference --input path/to/images_dir --save-empty
```

### 图形界面模式

```bash
python -m src.core.inference --gui
```

## 参数说明

- `--input`: 输入图像路径或目录（必需）
- `--output`: 输出目录路径，默认为输入目录名+_results
- `--threshold`: 检测置信度阈值，默认0.5
- `--max-bbox-ratio`: 检测框最大面积比例阈值，默认0.05
- `--save-empty`: 是否保存未检测到目标的图片
- `--gui`: 启用图形界面选择输入目录

## 输出说明

程序会在输出目录中生成以下内容：

- 检测结果图片（带检测框）
- `detection_report.csv`: 检测报告，包含以下信息：
  - 图片路径
  - 检测时间
  - 是否检测到目标
  - 检测框坐标
  - 置信度分数

## 注意事项

1. 确保模型文件路径正确
2. 如果使用GPU加速，请确保CUDA环境配置正确
3. 批量处理时建议使用相对较小的图片尺寸以提高处理速度
4. 检测报告会自动覆盖同名文件，请注意备份

## 更新日志

### 2024-03-29
- 移除Excel报告生成功能
- 优化检测报告生成逻辑
- 修复模型加载和属性访问问题